This is a python project.

## Installation

Install the current version with PyPI:

pip install superior6564

Or from Github:

pip install https://github.com/Superior-GitHub/Superior6564/archive/refs/heads/main.zip

## Usage

Before using you need to run packages.required()

It will check for the necessary libraries and install them if needed.

## Contributing

Bug reports and/or pull requests are welcome

## License 

The module is available as open source under the terms of the [Apache License, Version 2.0](https://opensource.org/licenses/Apache-2.0)